aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--tools/syz-trace2syz/proggen/proggen.go3
-rw-r--r--tools/syz-trace2syz/proggen/unsupported_calls.go (renamed from tools/syz-trace2syz/config/unsupported_calls.go)8
2 files changed, 5 insertions, 6 deletions
diff --git a/tools/syz-trace2syz/proggen/proggen.go b/tools/syz-trace2syz/proggen/proggen.go
index a3387ea15..70678fd52 100644
--- a/tools/syz-trace2syz/proggen/proggen.go
+++ b/tools/syz-trace2syz/proggen/proggen.go
@@ -9,7 +9,6 @@ import (
"github.com/google/syzkaller/pkg/log"
"github.com/google/syzkaller/prog"
- "github.com/google/syzkaller/tools/syz-trace2syz/config"
"github.com/google/syzkaller/tools/syz-trace2syz/parser"
)
@@ -363,7 +362,7 @@ func reorderStructFields(syzType *prog.StructType, traceType *parser.GroupType,
func shouldSkip(ctx *Context) bool {
syscall := ctx.CurrentStraceCall
- if config.ShouldSkip[syscall.CallName] {
+ if unsupportedCalls[syscall.CallName] {
return true
}
switch syscall.CallName {
diff --git a/tools/syz-trace2syz/config/unsupported_calls.go b/tools/syz-trace2syz/proggen/unsupported_calls.go
index e2453c2ba..3b677fc2a 100644
--- a/tools/syz-trace2syz/config/unsupported_calls.go
+++ b/tools/syz-trace2syz/proggen/unsupported_calls.go
@@ -1,12 +1,12 @@
// Copyright 2018 syzkaller project authors. All rights reserved.
// Use of this source code is governed by Apache 2 LICENSE that can be found in the LICENSE file.
-package config
+package proggen
var (
- // ShouldSkip lists system calls that we should skip when parsing
- // Some of these are unsupported or not worth executing
- ShouldSkip = map[string]bool{
+ // unsupportedCalls lists system calls that we should skip when parsing.
+ // Some of these are unsupported or not worth executing.
+ unsupportedCalls = map[string]bool{
// While we have system call descriptions for execve it is not worth adding
// the ones in traces. Every trace has an execve at the beginning which means
// all the system calls afterwards will not execute